%% Copyright (c) 2012 Miguel Bazdresch
%%
%% Permission is hereby granted, free of charge, to any person obtaining a
%% copy of this software and associated documentation files (the "Software"),
%% to deal in the Software without restriction, including without limitation
%% the rights to use, copy, modify, merge, publish, distribute, sublicense,
%% and/or sell copies of the Software, and to permit persons to whom the
%% Software is furnished to do so, subject to the following conditions:
%%
%% The above copyright notice and this permission notice shall be included in
%% all copies or substantial portions of the Software.
%%
%% THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
%% IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
%% FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
%% AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
%% LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
%% FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
%% DEALINGS IN THE SOFTWARE.

%% usage: p = avgpower( t, x )
%%
%% Estimate an analog signal's average power from a vector of its samples, in
%% a finite time interval defined by vector t.
%%
%% Input arguments:
%%   t : a time vector
%%   x : samples of an analog, finite-duration signal
%%
%% Output:
%%   p : average signal power over interval t

%% Author: Miguel Bazdresch

function p = avgpower( t, x )

	if nargin < 2
		usage( 'Two arguments are required.' );
	end
	if numel(t) != numel(x)
		usage( 'Input vectors must be the same size.' );
	end
	p = 1/(t(end)-t(1))*trapz(t,x.*x);

end
